<?php
/**
 * Aliases for invisible Math special pages
 *
 * There is no need to translate the messages, since the PageTitle does not appear.
 *
 * @see Math.alias.php for special pages with visible titles.
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = [];

/** English (English) */
$specialPageAliases['en'] = [
	'MathShowImage' => [ 'MathShowImage' ]
];
